@@ -40,6 +40,11 @@ if ! command -v $GUILE > /dev/null; then
     GUILE=true
 fi
 
+test_sh=${test_sh-${srcdest}build-aux/test.sh}
+if [ "$arch" = "x86_64-mes" ]; then
+    test_sh=${srcdest}build-aux/test64.sh
+fi
+
 tests="
 t
 00-exit-0
@@ -49,8 +54,15 @@ t
 04-call-0
 05-call-1
 06-call-!1
+06-!call-1
+06-call-2
+06-call-string
+06-call-variable
+06-return-void
 07-include
 08-assign
+08-assign-negative
+08-assign-global
 10-if-0
 11-if-1
 12-if-==
@@ -58,53 +70,100 @@ t
 14-if-goto
 15-if-!f
 16-if-t
+17-compare-ge
+17-compare-gt
+17-compare-le
+17-compare-lt
+17-compare-unsigned-ge
+17-compare-unsigned-gt
+17-compare-unsigned-le
+17-compare-unsigned-lt
+17-compare-unsigned-char-le
+17-compare-unsigned-short-le
+17-compare-unsigned-long-le
+17-compare-and
+17-compare-or
+17-compare-and-or
+17-compare-assign
+17-compare-call
+18-assign-shadow
 20-while
+21-char[]-simple
 21-char[]
 22-while-char[]
+23-global-pointer-init-null
+23-global-pointer-init
+23-global-pointer-ref
+23-global-pointer-pointer-ref
+23-pointer-sub
 23-pointer
 30-strlen
-31-eputs
+31-oputs
+32-call-wrap
 32-compare
 33-and-or
 34-pre-post
 35-compare-char
 36-compare-arithmetic
 37-compare-assign
+38-compare-call-2
+38-compare-call-3
 38-compare-call
 40-if-else
 41-?
 42-goto-label
 43-for-do-while
 44-switch
+44-switch-fallthrough
+44-switch-body-fallthrough
 45-void-call
 46-function-static
 47-function-expression
-48-function-destruct
-49-global-static
-4a-char-array
+48-global-static
 50-assert
+51-pointer-sub
+51-itoa
 51-strcmp
 51-strncmp
-52-itoa
 53-strcpy
+54-argc
 54-argv
+55-char-array
 60-math
 61-array
 62-array
+63-struct
+63-struct-pointer
+63-struct-local
+63-struct-function
+63-struct-assign
+63-struct-array
+63-struct-array-assign
+63-struct-array-compare
 63-struct-cell
 64-make-cell
 65-read
+66-local-char-array
+70-strchr
+70-stdarg
+70-printf-hello
+70-printf-simple
 70-printf
 71-struct-array
 72-typedef-struct-def
+73-union-hello
 73-union
 74-multi-line-string
 75-struct-union
+76-pointer-arithmetic-pp
 76-pointer-arithmetic
 77-pointer-assign
 78-union-struct
+79-int-array-simple
 79-int-array
 7a-struct-char-array
+7b-struct-int-array-hello
+7b-struct-int-array-pointer
 7b-struct-int-array
 7c-dynarray
 7d-cast-char
@@ -112,17 +171,33 @@ t
 7f-struct-pointer-arithmetic
 7g-struct-byte-word-field
 7h-struct-assign
+7i-struct-struct-simple
 7i-struct-struct
 7j-strtoull
+7k-empty-for
+7k-for-each-elem-simple
 7k-for-each-elem
+7l-struct-any-size-array-simple
 7l-struct-any-size-array
 7m-struct-char-array-assign
 7n-struct-struct-array
+7o-struct-pre-post-simple
 7o-struct-pre-post
 7p-struct-cast
+7q-bit-field-simple
 7q-bit-field
 7r-sign-extend
 7s-struct-short
+7s-unsigned-compare
+7t-function-destruct
+7u-double
+7u-long-long
+7u-?-expression
+7u-call-?
+7u-inc-byte-word
+7u-struct-func
+7u-struct-size10
+7u-vstack
 80-setjmp
 81-qsort
 81-qsort-dupes
@@ -133,6 +208,7 @@ t
 86-strncpy
 87-sscanf
 88-strrchr
+90-strspn
 90-strpbrk
 91-fseek
 92-stat
@@ -143,11 +219,20 @@ t
 97-fopen
 98-fopen
 99-readdir
+a0-call-trunc-char
+a0-call-trunc-short
+a0-call-trunc-int
+a0-math-divide-signed-negative
+a1-global-no-align
+a1-global-no-clobber
 "
 
-# 90: needs GNU, fails for mescc, passes for tcc
 broken="$broken
-7s-struct-short
+17-compare-unsigned-char-le
+17-compare-unsigned-short-le
+66-local-char-array
+a0-call-trunc-int
+a0-math-divide-signed-negative
 "
 
 # gcc not supported
@@ -175,7 +260,7 @@ for t in $tests; do
         LIBC=c
         MES_LIBS=
     fi
-    sh ${srcdest}build-aux/test.sh "scaffold/tests/$t" &> scaffold/tests/"$t".log
+    sh $test_sh "scaffold/tests/$t" &> scaffold/tests/"$t".log
     r=$?
     total=$((total+1))
     if [ $r = 0 ]; then
