@@ -17,6 +17,7 @@
 # along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
 
 srcdir=${srcdir-.}
+top_builddir=${top_builddir-.}
 if [ "$V" = 2 ]; then
     echo $0
     echo srcdest=${srcdest}
@@ -152,7 +153,8 @@ MES_CPPFLAGS=${MES_CPPFLAGS-"
 MES_CFLAGS=${MES_CFLAGS-"
 "}
 
-MES_CFLAGS=${MES_CFLAGS-"
+MES64_CFLAGS=${MES64_CFLAGS-"
+-m64
 "}
 
 M1FLAGS=${M1FLAGS-"
