@@ -68,32 +68,39 @@
         (_ #f)))))
 
 (define-public nyacc-for-mes
-  (package
-    (inherit nyacc)
-    (version "0.80.42")
+  (let ((commit "ba24561b77306cd876bb9fd5ac412b15c7535f02")
+        (revision "0")
+        (version "0.86.0"))
+    (package
+      (inherit nyacc)
+      (version (if commit (string-append version "-" revision "." (string-take commit 7))
+                   version))
       (source (origin
                 (method url-fetch)
-                (uri (string-append "https://gitlab.com/janneke/nyacc"
-                                    "/-/archive/v" version
-                                    "/nyacc-" version ".tar.gz"))
+                (uri (if commit
+                         (string-append "http://git.savannah.nongnu.org/cgit/nyacc.git/snapshot/nyacc-"
+                                        commit ".tar.gz")
+                         (string-append "http://download.savannah.nongnu.org/releases/nyacc/nyacc-"
+                                        version ".tar.gz")))
                 (sha256
                  (base32
-                  "0c8c8kxir0h2d4nxr131xbkfs7c80haipmkp2g6677sh14wn0b3y"))))))
+                  "08y8ihwm21i333w7b0g1gs4s184ky0wy6fnl1rcakpgrqan9r1ql")))))))
 
 (define-public mescc-tools
   (package
     (name "mescc-tools")
-    (version "0.5.1")
-    (source (origin
-              (method url-fetch)
-              (uri (string-append
-                    "https://github.com/oriansj/mescc-tools/archive/Release_"
-                    version
-                    ".tar.gz"))
-              (file-name (string-append name "-" version ".tar.gz"))
-              (sha256
-               (base32
-                "0rsxbjc3bg0jl3h7ai4hndxx2iyyk8bvwj9nd3xv2vgz3bmypnah"))))
+    (version "0.5.2")
+     (source (origin
+               (method url-fetch)
+               (uri (string-append "http://git.savannah.nongnu.org/cgit/"
+                                   "mescc-tools.git/snapshot/"
+                                   "mescc-tools-Release_" version
+                                   ".tar.gz"))
+               (patches (search-patches "mescc-tools-boot.patch"))
+               (file-name (string-append name "-" version ".tar.gz"))
+               (sha256
+                (base32
+                 "01x7bhmgwyf6mc2g1hcvibhps98nllacqm4f0j5l51b1mbi18pc2"))))
     (build-system gnu-build-system)
     (supported-systems '("i686-linux" "x86_64-linux"))
     (arguments
@@ -111,7 +118,7 @@ hex2 linker.")
 
 (define-public mes
   (let ((triplet "i686-unknown-linux-gnu")
-        (version "0.17.1"))
+        (version "0.18"))
     (package
       (name "mes")
       (version version)
@@ -120,7 +127,7 @@ hex2 linker.")
                 (uri (string-append
                       "https://ftp.gnu.org/pub/gnu/mes/mes-" version ".tar.gz"))
                 (sha256
-                 (base32 #!mes!# "1j32x4zqy2cqjlg9m35f2411mwac2b0p5ch4hm99gddmfbxzgyhg"))))
+                 (base32 #!mes!# "02g8zig53ffd0ai8kqhv2zj7bj2366a8hr6ydkwakmi2d1amyrna"))))
       (build-system gnu-build-system)
       (supported-systems '("i686-linux" "x86_64-linux"))
       (propagated-inputs
@@ -158,7 +165,7 @@ Guile-] Scheme interpreter prototype in C and a Nyacc-based C compiler in
       (license gpl3+))))
 
 (define-public mes.git
- (let ((version "0.17.1")
+ (let ((version "0.18")
         (revision "0")
         (commit (read-string (open-pipe "git show HEAD | head -1 | cut -d ' ' -f 2" OPEN_READ))))
     (package
