@@ -25,12 +25,6 @@
 #include_next <stddef.h>
 #else // ! WITH_GLIBC
 
-#ifndef __MES_SIZE_T
-#define __MES_SIZE_T
-#undef size_t
-typedef unsigned long size_t;
-#endif
-
 #include <sys/types.h>
 #include <stdint.h>
 #include <unistd.h>
