@@ -21,7 +21,7 @@
 #include <libmes.h>
 
 char const*
-utoa (unsigned long x)
+utoa (unsigned x)
 {
   return ntoab (x, 10, 0);
 }
