@@ -26,9 +26,47 @@
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-26)
   #:use-module (nyacc lang c99 parser)
+  #:use-module (nyacc lang c99 parser)
+  #:use-module (nyacc version)
   #:use-module (mes guile)
   #:export (c99-input->ast))
 
+(when (getenv "MESC_DEBUG")
+  (format (current-error-port) "*nyacc-version*=~a\n" *nyacc-version*))
+
+;; list of which rules you want progress reported
+(define need-progress
+  (or (assoc-ref
+       '(("0.85.3" (1 2 3))
+         ("0.86.0" (1 2 3)))
+       *nyacc-version*)
+      '(1 2 3)))
+
+(define (progress o)
+  (when (and o (getenv "NYACC_DEBUG"))
+    (display "    :" (current-error-port))
+    (display o (current-error-port))
+    (display "\n" (current-error-port))))
+
+(define (insert-progress-monitors act-v len-v)
+  (let ((n (vector-length act-v)))
+    (let loop ((ix 0))
+      (when (< ix n)
+	(if (memq ix need-progress)
+	    (vector-set
+	     act-v ix
+	     (lambda args
+	       (progress (list-ref args (1- (vector-ref len-v ix))))
+	       (apply (vector-ref act-v ix) args))))
+        (loop (1+ ix))))))
+
+(cond-expand
+ (guile
+  (insert-progress-monitors (@@ (nyacc lang c99 parser) c99-act-v)
+                            (@@ (nyacc lang c99 parser) c99-len-v)))
+ (mes
+  (insert-progress-monitors c99-act-v c99-len-v)))
+
 (define (logf port string . rest)
   (apply format (cons* port string rest))
   (force-output port)
@@ -46,7 +84,6 @@
      #:cpp-defs `(
                   "NULL=0"
                   "__linux__=1"
-                  "__i386__=1"
                   "POSIX=0"
                   "_POSIX_SOURCE=0"
                   "__STDC__=1"
