@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -18,14 +18,16 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "30-test.i"
+#include <libmes-mini.h>
 
 int
-test ()
+main ()
 {
-  if (strlen ("mes") == 3) goto ok;
+  if (strlen ("mes") == 3)
+    goto ok;
   return 1;
  ok:
-  if (strlen ("mes") != 3) return 1;
+  if (strlen ("mes") != 3)
+    return 1;
   return 0;
 }
