@@ -18,12 +18,12 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "30-test.i"
+#include <libmes.h>
 #include <assert.h>
 #include <stdio.h>
 
 int
-test ()
+main ()
 {
   int f;
 
