@@ -19,8 +19,6 @@
  */
 
 #include <libmes.h>
-#include <assert.h>
-#include <stdio.h>
 #include <string.h>
 
 int
