@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -18,23 +18,27 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <libmes.h>
+
 #include <stdio.h>
 #include <string.h>
 
 int
 main (int argc, char *argv[])
 {
-  puts ("\n");
-  puts ("t: argv[0] == \"scaffold/test....\"\n");
-  puts ("argv0="); puts (argv[0]); puts ("\n");
-  if (strncmp (argv[0], "scaffold/test", 5)) return 1;
+  oputs ("\n");
+  oputs ("t: argv[0] == \"scaffold/test....\"\n");
+  oputs ("argv0="); oputs (argv[0]); oputs ("\n");
+  if (strncmp (argv[0], "scaffold/test", 5))
+    return 1;
 
-  puts ("t: *argv\"\n");
-  puts (*argv);
-  puts ("\n");
+  oputs ("t: *argv\"\n");
+  oputs (*argv);
+  oputs ("\n");
 
-  puts ("t: if (argc > 1 && !strcmp (argv[1], \"--help\")\n");
-  if (argc > 1 && !strcmp (argv[1], "--help")) return 2;
+  oputs ("t: if (argc > 1 && !strcmp (argv[1], \"--help\")\n");
+  if (argc > 1 && !strcmp (argv[1], "--help"))
+    return 2;
 
   return 0;
 }
