@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -28,6 +28,9 @@ struct foo {
   int b;
   int c;
   unsigned char *d;
+#if __MESC__ && __x86_64__
+  int __align;
+#endif
 };
 
 int
@@ -39,88 +42,133 @@ main ()
   char **ppc = 0;
   void **ppv = 0;
   int **ppi = 0;
+  int int_size = sizeof (int);
+  int ptr_size = sizeof (void*);
+  int foo_size = sizeof (struct foo);
+  oputs ("int_size:"); oputs (itoa (int_size)); oputs ("\n");
+  oputs ("ptr_size:"); oputs (itoa (ptr_size)); oputs ("\n");
+  oputs ("foo_size:"); oputs (itoa (foo_size)); oputs ("\n");
+  // FIXME: add *14, *18
+#if __i386__
+  int foo_size_14 = 224;
+  int foo_size_18 = 288;
+#elif __x86_64__
+  int foo_size_14 = 336;
+  int foo_size_18 = 432;
+#endif
 
-  if (++pc != 1) return 1;
-  if (++pv != 1) return 2;
-  if (++pi != 4) return 3;
-  if (++ppc != 4) return 4;
-  if (++ppv != 4) return 5;
-  if (++ppi != 4) return 6;
-  if (pc + 1 != 2) return 7;
-  if (pv + 1 != 2) return 8;
-  if (pi + 1 != 8) return 9;
-  if (ppc + 1 != 8) return 10;
-  if (ppv + 1 != 8) return 11;
-  if (ppi + 1 != 8) return 12;
+  if (++pc != 1)
+    return 1;
+  if (++pv != 1)
+    return 2;
+  if (++pi != int_size)
+    return 3;
+  if (++ppc != ptr_size)
+    return 4;
+  if (++ppv != ptr_size)
+    return 5;
+  if (++ppi != ptr_size)
+    return 6;
+  if (pc + 1 != 2)
+    return 7;
+  if (pv + 1 != 2)
+    return 8;
+  if (pi + 1 != int_size << 1)
+    return 9;
+  if (ppc + 1 != ptr_size << 1)
+    return 10;
+  if (ppv + 1 != ptr_size << 1)
+    return 11;
+  if (ppi + 1 != ptr_size << 1)
+    return 12;
 
   char **p = list;
   ++*p;
   eputs (*p);
-  if (strcmp (*p, "oo\n")) return 13;
+  if (strcmp (*p, "oo\n"))
+    return 13;
   --*p;
   eputs (*p);
-  if (strcmp (*p, "foo\n")) return 14;
+  if (strcmp (*p, "foo\n"))
+    return 14;
 
   struct foo* pfoo = 0;
   eputs ("pfoo="); eputs (itoa (pfoo)); eputs ("\n");
   pfoo++;
   eputs ("pfoo="); eputs (itoa (pfoo)); eputs ("\n");
-  if (pfoo != 16) return 15;
+  if (pfoo != foo_size)
+    return 15;
 
   pfoo--;
   eputs ("pfoo="); eputs (itoa (pfoo)); eputs ("\n");
-  if (pfoo) return 16;
+  if (pfoo)
+    return 16;
 
   pfoo++;
   eputs ("pfoo="); eputs (itoa (pfoo)); eputs ("\n");
-  if (pfoo != 16) return 17;
+  if (pfoo != foo_size)
+    return 17;
 
-  int one = 1;
-  int two = 2;
+  long one = 1;
+  long two = 2;
   pfoo = pfoo - one;
   eputs ("pfoo="); eputs (itoa (pfoo)); eputs ("\n");
-  if (pfoo) return 18;
+  if (pfoo)
+    return 18;
 
   pfoo = pfoo + one;
   eputs ("pfoo="); eputs (itoa (pfoo)); eputs ("\n");
-  if (pfoo != 16) return 19;
+  if (pfoo != foo_size)
+    return 19;
 
   pfoo -= one;
   eputs ("pfoo="); eputs (itoa (pfoo)); eputs ("\n");
-  if (pfoo) return 20;
+  if (pfoo)
+    return 20;
 
   pfoo += one;
   eputs ("pfoo="); eputs (itoa (pfoo)); eputs ("\n");
-  if (pfoo != 16) return 21;
+  if (pfoo != foo_size)
+    return 21;
 
-  if (&one - 1 != &two) return 22;
+  eputs ("&one: "); eputs (itoa (&one)); eputs ("\n");
+  eputs ("&two: "); eputs (itoa (&two)); eputs ("\n");
 
-  struct foo* sym = 32;
-  int d = 16;
+  if (&one - 1 != &two)
+    return 22;
+
+  struct foo* sym = foo_size + foo_size;
   int i = sym + 16;
   eputs ("i="); eputs (itoa (i)); eputs ("\n");
-  if (i != 288) return 23;
+  if (i != foo_size_18)
+    return 23;
 
+  int d = 16;
   i = sym + d;
   eputs ("i="); eputs (itoa (i)); eputs ("\n");
-  if (i != 288) return 24;
+  if (i != foo_size_18)
+    return 24;
 
   i = sym - 16;
   eputs ("i="); eputs (itoa (i)); eputs ("\n");
-  if (i != -224) return 25;
+  if (i != -foo_size_14)
+    return 25;
 
   i = sym - d;
   eputs ("i="); eputs (itoa (i)); eputs ("\n");
-  if (i != -224) return 26;
+  if (i != -foo_size_14)
+    return 26;
 
-  i = sym - (struct foo*)d;
+  i = sym - (struct foo*)foo_size;
   eputs ("i="); eputs (itoa (i)); eputs ("\n");
-  if (i != 1) return 27;
+  if (i != 1)
+    return 27;
 
   pfoo = sym + 1;
   pfoo -= sym;
   eputs ("pfoo="); eputs (itoa (pfoo)); eputs ("\n");
-  if (pfoo != 1) return 28;
+  if (pfoo != 1)
+    return 28;
 
   return 0;
 }
